import { Router } from '@angular/router';
import { HttpClient } from '@angular/common/http';
import { MatSnackBarHorizontalPosition, MatSnackBarVerticalPosition } from '@angular/material';
import { BehaviorSubject, Observable } from 'rxjs';
import { NotifyService } from '../../shared/components/notification/notify.service';
/**
 * 数据服务API访问封装服务，提供token注入、数据预处理、及错误预处理
 */
export declare class FetchService {
    private http;
    private router;
    private notifyService;
    loadingStatusChange: BehaviorSubject<Set<string>>;
    constructor(http: HttpClient, router: Router, notifyService: NotifyService);
    /**
     * 构建数据获取服务，预定义token封装，错误处理
     * @param url 请求地址
     * @param params 请求参数
     * @param fetchCallbackConfig 预处理相关配置。具体参见 {@link FetchCallbackConfig}
     * @returns Observable<T>
     */
    get<T>(url: string, params?: {
        [param: string]: any;
    }, fetchCallbackConfig?: FetchCallbackConfig): Observable<T>;
    /**
     * POST请求服务
     * @param url 请求地址
     * @param data POST发送数据
     * @param fetchCallbackConfig 预处理相关配置。具体参见 {@link FetchCallbackConfig}
     * @returns Observable<T>
     */
    post<T>(url: string, data: Object, fetchCallbackConfig?: FetchCallbackConfig): Observable<T>;
    private handleResponse;
    private handleError;
    private pushLoadingQueue;
    private shiftLoadingQueue;
}
/**
 * FetchService调用预处理、后处理相关设置
 */
export interface FetchCallbackConfig {
    /** response数据内容标签，默认为data */
    responseData?: string;
    /** error数据内容标签，默认为error */
    errorData?: string;
    /** 是否显示成功操作提示，默认为true */
    showNotify?: boolean;
    /** 是否显示操作失败提示，默认为true */
    showError?: boolean;
    /** 操作成功提示消息设置选项 */
    notifyOptions?: {
        notifyTitle?: string;
        notifyMessage?: string;
        notifyHorizontalPosition?: MatSnackBarHorizontalPosition;
        notifyVerticalPosition?: MatSnackBarVerticalPosition;
    };
    /** 操作失败提示消息设置选项 */
    errorNotifyOptions?: {
        /** * 失败提示类型，可以为toast或alert，默认为alert */
        errorNotifyType?: string;
        errorNotifyTitle?: string;
        errorNotifyMessage?: string;
    };
    headerOptions?: {
        [name: string]: string | Array<string>;
    };
}
