import { EventEmitter, OnDestroy, OnInit, ViewContainerRef } from '@angular/core';
import { CascadeSelectItemModel, CascadeSelectService, SelectedModel } from './cascade-select.service';
import { Subject } from 'rxjs';
import { UpCascadeSelectInputDirective } from './cascade-select-input.directive';
import { Overlay, OverlayRef } from '@angular/cdk/overlay';
import { CascadeSelectOverlayComponent } from './cascade-select-overlay/cascade-select-overlay.component';
export declare class UpCascadeSelectContentComponent {
    class: string;
    /** Reference to the internal overlay component. */
    _overlayContent: CascadeSelectOverlayComponent;
    /** Reference to the cascadeSelect that created the overlay. */
    cascadeSelect: CascadeSelectComponent;
}
export declare class CascadeSelectComponent implements OnInit, OnDestroy {
    private cascadeSelectService;
    private _overlay;
    private _viewContainerRef;
    private _document;
    selectedValue: Subject<SelectedModel | SelectedModel[]>;
    finalValue: SelectedModel | Array<SelectedModel>;
    keywords: string;
    /**
     * 最小的level 对可选中item的层级限制
     */
    minSelectable: number;
    /**
     * 最大的level 对可展开item的层级限制
     */
    maxSelectable: number;
    /**
     * dropdown的最大高度
     */
    height: number;
    /**
     * 多选
     */
    multiple: boolean;
    opened: boolean;
    private _opened;
    dataSource: Array<CascadeSelectItemModel>;
    _dataSource: Array<CascadeSelectItemModel>;
    /** Whether the cascadeSelectOverlay pop-up should be disabled. */
    disabled: boolean;
    private _disabled;
    /** Emits when the cascadeSelectOverlay is disabled. */
    readonly _disabledChange: Subject<boolean>;
    /**
     * 搜索结果
     */
    searchResults: Array<CascadeSelectItemModel>;
    /**
     * 自定义输入层级title
     */
    levelNameList: Array<string>;
    /**
     * 传入的近期选择列表
     */
    latestSelections: Array<any>;
    /**
     * 是否显示搜索框 默认不显示
     */
    isSearchable: boolean;
    /**
     * 默认id 如果有 从该id下的层级开始展开显示
     */
    defaultId: string;
    /**
     * 搜索
     */
    readonly inputSearch: EventEmitter<any>;
    /**
     * 选中项change
     */
    readonly selectedOnChange: EventEmitter<any>;
    /**
     * item被点击
     */
    readonly itemOnClick: EventEmitter<any>;
    /**
     * 移除近期选择
     */
    readonly removeLatestSelection: EventEmitter<any>;
    /** Emits when the selectOverlay has been opened. */
    readonly dropdownOpened: EventEmitter<any>;
    /** Emits when the selectOverlay has been closed. */
    readonly dropdownClosed: EventEmitter<any>;
    readonly clear: EventEmitter<any>;
    inputValue: SelectedModel | Array<SelectedModel>;
    _cascadeSelectInput: UpCascadeSelectInputDirective;
    /** A reference to the overlay when the cascadeSelect is opened as a popup. */
    _popupRef: OverlayRef;
    /** A portal containing the content for this overlay. */
    private _overlayContent;
    /** Reference to the component instantiated in popup mode. */
    private _popupComponentRef;
    /** The element that was focused before the cascadeSelect was opened. */
    private _focusedElementBeforeOpen;
    /** Subscription to value changes in the associated input element. */
    private _inputSubscription;
    constructor(cascadeSelectService: CascadeSelectService, _overlay: Overlay, _viewContainerRef: ViewContainerRef, _document: any);
    ngOnInit(): void;
    ngOnDestroy(): void;
    search(e: any): void;
    changeSelected(e: any): void;
    itemClicked(e: any): void;
    /**
     * remove 近期选择中选项
     */
    removeLatestItem(e: any): void;
    /** Create the popup PositionStrategy. */
    private _createPopupPositionStrategy;
    private _createPopup;
    /**
     * Register an input with this overlay.
     * @param input The overlay input to register with this overlay.
     */
    _registerInput(input: UpCascadeSelectInputDirective): void;
    /** Open the overlay as a popup. */
    private _openAsPopup;
    /** Open the overlay. */
    open(): void;
    /** Close the overlay. */
    close(): void;
    clearInput(): void;
}
