import { FloatLabelType } from '@angular/material';
import { FormGroup } from '@angular/forms';
import { Type } from '@angular/core';
import { UPValidatorFn, UPAsyncValidatorFn } from '../dynamic-validators/validators.service';
/**
 * 表单控件配置项
 */
export interface UPDynamicFormFieldConfig<T> {
    /**
     * 表单字段名
     */
    fieldId: string;
    /**
     * 内置控件类型 'input' | 'select' | 'textarea' | 'date' | 'radio' | 'checkbox' | 'autocomplete' | 'file'
     */
    controlType: UPDynamicFormControlType | Type<FieldControl<any>>;
    /**
     * @Deprecated 请直接使用controlType
     * 为自定义组件预留，alpha中，如有需求，请联系 @张瑞
     */
    component?: Type<FieldControl<any>>;
    /**
     * 初始值
     */
    value?: any;
    /**
     * 所占水平格数
     */
    cols?: number;
    /**
     * 所占垂直格数
     */
    rows?: number;
    /**
     * 隐藏控件，同时屏蔽验证
     */
    hide?: boolean;
    /**
     * 标签内容
     */
    labelText?: string;
    /**
     * 标签样式，inline或者在控件左侧
     */
    labelStyle?: FloatLabelType | 'left';
    /**
     * 占位提示语
     */
    placeholder?: string;
    /**
     * 是否显示必填标识，不影响验证器，仅影响样式
     */
    showRequired?: boolean;
    /**
     * 同步验证器
     */
    validators?: UPValidatorFn | Array<UPValidatorFn>;
    /**
     * 异步验证器
     */
    asyncValidators?: UPAsyncValidatorFn | Array<UPAsyncValidatorFn>;
    /**
     * 是否只读
     */
    readonly?: boolean;
    /**
     * 选项, select | radiogroup 等控件需要
     */
    options?: Array<{
        label: any;
        value: any;
    }>;
    /**
     * 控件自有属性
     * 目前是any，属性将被透传，未来扩展T为专有Type
     */
    controlProps?: T;
    /**
     * 控件下方提示语
     */
    hint?: string;
    /**
     * field值更新
     */
    valueChange?: (value: any) => void;
}
export declare type UPDynamicFormControlType = 'input' | 'select' | 'textarea' | 'date' | 'radio' | 'checkbox' | 'autocomplete' | 'file' | 'pathSelect';
/**
 * 实现自定义控件，需要实现此接口，该接口字段将被赋值，自定义的控件可以使用这些字段
 * 其中必须有实现了 @interface ControlValueAccesser 的控件，并实现类似结构
 * formControlName="{{fieldId}}"
 */
export interface FieldControl<T> {
    fieldConfig: UPDynamicFormFieldConfig<T>;
    floatLabel?: FloatLabelType;
    /**
     * 控件自有属性
     * 目前是any，属性将被透传，未来扩展T为专有Type
     */
    properties: T;
    /**
     * 表单对象
     */
    form: FormGroup;
}
